using System;
using System.Text.Json.Serialization;
namespace concerto.metamodel {
   using concerto;
   abstract class DecoratorLiteral : Concept {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.DecoratorLiteral";
   }
   class DecoratorString : DecoratorLiteral {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.DecoratorString";
      public string value { get; set; }
   }
   class DecoratorNumber : DecoratorLiteral {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.DecoratorNumber";
      public float value { get; set; }
   }
   class DecoratorBoolean : DecoratorLiteral {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.DecoratorBoolean";
      public bool value { get; set; }
   }
   class TypeIdentifier : Concept {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.TypeIdentifier";
      public string fullyQualifiedName { get; set; }
   }
   class DecoratorIdentifier : DecoratorLiteral {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.DecoratorIdentifier";
      public TypeIdentifier identifier { get; set; }
      public bool isArray { get; set; }
   }
   class Decorator : Concept {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.Decorator";
      public string name { get; set; }
      public DecoratorLiteral[] arguments { get; set; }
   }
   abstract class ClassDeclaration : Concept {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.ClassDeclaration";
      public Decorator[] decorators { get; set; }
      public bool isAbstract { get; set; }
      public string identifier { get; set; }
      public string identifiedByField { get; set; }
      public TypeIdentifier superType { get; set; }
   }
   class AssetDeclaration : ClassDeclaration {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.AssetDeclaration";
   }
   class ParticipantDeclaration : ClassDeclaration {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.ParticipantDeclaration";
   }
   class TransactionDeclaration : ClassDeclaration {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.TransactionDeclaration";
   }
   class EventDeclaration : ClassDeclaration {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.EventDeclaration";
   }
   class ConceptDeclaration : ClassDeclaration {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.ConceptDeclaration";
   }
   class EnumDeclaration : ClassDeclaration {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.EnumDeclaration";
   }
   class StringDefault : Concept {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.StringDefault";
      public string value { get; set; }
   }
   class BooleanDefault : Concept {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.BooleanDefault";
      public bool value { get; set; }
   }
   class IntegerDefault : Concept {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.IntegerDefault";
      public int value { get; set; }
   }
   class RealDefault : Concept {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.RealDefault";
      public float value { get; set; }
   }
   abstract class FieldDeclaration : Concept {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.FieldDeclaration";
      public string name { get; set; }
      public bool isArray { get; set; }
      public bool isOptional { get; set; }
      public Decorator[] decorators { get; set; }
   }
   class ObjectFieldDeclaration : FieldDeclaration {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.ObjectFieldDeclaration";
      public StringDefault defaultValue { get; set; }
      public TypeIdentifier type { get; set; }
   }
   class BooleanFieldDeclaration : FieldDeclaration {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.BooleanFieldDeclaration";
      public BooleanDefault defaultValue { get; set; }
   }
   class DateTimeFieldDeclaration : FieldDeclaration {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.DateTimeFieldDeclaration";
   }
   class StringFieldDeclaration : FieldDeclaration {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.StringFieldDeclaration";
      public StringDefault defaultValue { get; set; }
      public StringRegexValidator validator { get; set; }
   }
   class StringRegexValidator : Concept {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.StringRegexValidator";
      public string regex { get; set; }
   }
   class RealDomainValidator : Concept {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.RealDomainValidator";
      public float lower { get; set; }
      public float upper { get; set; }
   }
   class IntegerDomainValidator : Concept {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.IntegerDomainValidator";
      public int lower { get; set; }
      public int upper { get; set; }
   }
   class RealFieldDeclaration : FieldDeclaration {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.RealFieldDeclaration";
      public RealDefault defaultValue { get; set; }
      public RealDomainValidator validator { get; set; }
   }
   class IntegerFieldDeclaration : FieldDeclaration {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.IntegerFieldDeclaration";
      public IntegerDefault defaultValue { get; set; }
      public IntegerDomainValidator validator { get; set; }
   }
   class RelationshipDeclaration : FieldDeclaration {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.RelationshipDeclaration";
      public TypeIdentifier type { get; set; }
   }
   abstract class Import : Concept {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.Import";
      public string uri { get; set; }
   }
   class NamespaceImport : Import {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.NamespaceImport";
      public string namespace { get; set; }
   }
   class TypeImport : Import {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.TypeImport";
      public TypeIdentifier identifier { get; set; }
   }
   class ModelFile : Concept {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "concerto.metamodel.ModelFile";
      public string namespace { get; set; }
      public Import[] imports { get; set; }
      public ClassDeclaration[] declarations { get; set; }
   }
}
